/*
 * DMScriptApi.cpp
 *
 * Copyright (C) 2010-2013 Julien Eychenne
 *
 * This file is part of Dolmen.
 *
 * Dolmen is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License (GPL) as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * Dolmen is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Dolmen. If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:  Julien Eychenne
 * Purpose: Top-level scripting API
 * Created: 06/03/2012
 */


#include "DMScriptApi.h"

DMScriptApi::DMScriptApi(QWidget *parent) :
    QObject(parent)
{
    this->setObjectName("Dolmen");
    m_widget = parent;
    m_engine = new QScriptEngine(this);
    m_mainPlugin = NULL;

    dialogApi = new DMDialogApi(this, parent);
    textApi = new DMTextApi(this);
    outputApi = new DMOutputApi(this);
    // set up script engine
    QScriptValue interfaceWrapper = m_engine->newQObject(this);
    m_engine->globalObject().setProperty("Dolmen", interfaceWrapper);
}

Plugin* DMScriptApi::mainPlugin() const
{
    return m_mainPlugin;
}

QScriptEngine* DMScriptApi::engine() const
{
    return m_engine;
}

QList<Plugin*> DMScriptApi::plugins() const
{
    return m_plugins;
}

void DMScriptApi::setMainPlugin(Plugin *p)
{
    m_mainPlugin = p;
}

void DMScriptApi::addPlugin(Plugin *p)
{
    if (!m_plugins.contains(p))
    {
        m_plugins.append(p);
        connect(p, SIGNAL(scriptCalled(QString,QString)), this, SLOT(executeScript(QString,QString)));
    }
}

bool DMScriptApi::executeMainPlugin()
{
    QString script = m_mainPlugin->scriptContent("main.js");
    QScriptValue retValue = m_engine->evaluate(script);

    return (!retValue.isError());

}

void DMScriptApi::executeScript(const QString &script, const QString &content)
{
    QScriptValue retval = m_engine->evaluate(content);

    if (retval.isError())
        QMessageBox::critical(m_widget, tr("Run-time error"), tr("The script %1 produced an error").arg(script));
}


DMScriptApi::~DMScriptApi()
{
    delete outputApi;
    delete dialogApi;
    delete textApi;
}
