/*
 * BookmarkBrowser.cpp
 *
 * Copyright (C) 2010-2013 Julien Eychenne
 *
 * This file is part of Dolmen.
 *
 * Dolmen is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License (GPL) as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * Dolmen is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Dolmen. If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:  Julien Eychenne
 * Purpose:
 * Created: 12/04/2011
 */

#include "BookmarkBrowser.h"

BookmarkBrowser::BookmarkBrowser(QWidget *parent) : QTreeWidget(parent)
{
	setFocusPolicy(Qt::NoFocus);

#ifdef Q_OS_MAC // color the sidebar (as in Mail or Finder)
	QPalette p(this->palette());
	p.setColor(QPalette::Base, "#dce4eb");
	setPalette(p);
	setStyleSheet("QTreeWidget { border: 0px; }");
#endif

	//setDragDropMode(QAbstractItemView::InternalMove);
	setContextMenuPolicy(Qt::CustomContextMenu);
	setSelectionMode(QAbstractItemView::ExtendedSelection);
	//setDropIndicatorShown(true);

	setEditTriggers(QAbstractItemView::SelectedClicked);

	QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
	sizePolicy.setHorizontalStretch(0);
	sizePolicy.setVerticalStretch(0);
	sizePolicy.setHeightForWidth(sizePolicy.hasHeightForWidth());
	setSizePolicy(sizePolicy);
	setFrameShadow(QFrame::Plain);

	connect(this, SIGNAL(itemDoubleClicked(QTreeWidgetItem*,int)), this, SLOT(onItemDoubleClicked(QTreeWidgetItem*)));
    connect(this, SIGNAL(itemClicked(QTreeWidgetItem*,int)), this, SLOT(onItemClicked(QTreeWidgetItem*)));
	connect(this, SIGNAL(customContextMenuRequested(const QPoint &)), SLOT(showContextMenu(const QPoint &)));

#ifdef Q_OS_MAC
	headerItem()->setHidden(true);
#else
	headerItem()->setText(0, "");
#endif
}

void BookmarkBrowser::redraw(QList<Bookmark *> bookmarks)
{	
	this->clear();

	foreach (Bookmark *bm, m_bookmarks)
	{
		if (bm->type() == "SearchMatch")
		{
			SearchMatch *qm = static_cast<SearchMatch*>(bm);
			disconnect(qm, SIGNAL(openDFile(DFile*,double,double)), this, SIGNAL(openDFile(DFile*,double,double)));
		}
	}

	m_bookmarks.clear();
	m_bookmarks = bookmarks;

	QIcon icon(":/icons/bookmark.png");
	foreach (Bookmark *bm, bookmarks)
	{
		QTreeWidgetItem *item = new QTreeWidgetItem(this);
		item->setText(0, bm->title());
		item->setToolTip(0, bm->tooltip());
		item->setIcon(0, icon);
		item->setData(0, Qt::UserRole, bm->id());

		if (bm->type() == "SearchMatch")
		{
			SearchMatch *qm = static_cast<SearchMatch*>(bm);
			connect(qm, SIGNAL(openDFile(DFile*,double,double)), this, SIGNAL(openDFile(DFile*,double,double)));
		}
	}
}

void BookmarkBrowser::onItemDoubleClicked(QTreeWidgetItem *item)
{
	Bookmark *bm = m_bookmarks.at(this->indexFromItem(item).row());
	bm->open();
}

void BookmarkBrowser::onItemClicked(QTreeWidgetItem *item)
{
    Bookmark *bm = m_bookmarks.at(this->indexFromItem(item).row());
    emit bookmarkClicked(bm);
}

void BookmarkBrowser::showContextMenu(const QPoint &pos)
{
	ContextMenu menu(this);
	QAction *rmBookmark = new QAction(tr("Remove"), this);
	menu.addAction(rmBookmark);
	connect(rmBookmark, SIGNAL(triggered()), this, SLOT(onRemoveBookmarks()));
	menu.display(pos);
}

void BookmarkBrowser::onRemoveBookmarks()
{
	QList<Bookmark*> lst;

	foreach (QTreeWidgetItem *item, selectedItems())
	{
		bool ok;
		int id = item->data(0, Qt::UserRole).toInt(&ok);

		if (ok)
		{
			Bookmark *bm = this->bookmarkFromId(id);
			if (bm)
				lst << bm;
		}
	}

	emit removeBookmarks(lst);
}

Bookmark *BookmarkBrowser::bookmarkFromId(int id) const
{
	foreach(Bookmark *bm, m_bookmarks)
	{
		if (bm->id() == id)
			return bm;
	}

	return NULL;
}









