/*
 * BookmarkBrowser.h
 *
 * Copyright (C) 2010-2013 Julien Eychenne
 *
 * This file is part of Dolmen.
 *
 * Dolmen is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License (GPL) as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * Dolmen is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Dolmen. If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:  Julien Eychenne
 * Purpose: browse bookmarks
 * Created: 12/04/2011
 */

#ifndef BOOKMARKBROWSER_H
#define BOOKMARKBROWSER_H

#include <QWidget>
#include <QTreeWidget>
#include <QVBoxLayout>
#include <QList>

#include "lib/Bookmark.h"
#include "lib/DFile.h"
#include "gui/ContextMenu.h"
#include "search/SearchMatch.h"

class BookmarkBrowser : public QTreeWidget
{
	Q_OBJECT

public:
	BookmarkBrowser(QWidget *parent = NULL);

signals:
	void openDFile(DFile *df, double start, double end);
	void removeBookmarks(QList<Bookmark*>);
    void bookmarkClicked(Bookmark *bm);

public slots:
	void redraw(QList<Bookmark*>);

private slots:
	void onItemDoubleClicked(QTreeWidgetItem *);
    void onItemClicked(QTreeWidgetItem *);
	void showContextMenu(const QPoint &);
	void onRemoveBookmarks();

private:
	QList<Bookmark*> m_bookmarks;

	Bookmark* bookmarkFromId(int id) const;


};

#endif // BOOKMARKBROWSER_H
