/*
 * SideBar.cpp
 *
 * Copyright (C) 2010-2013 Julien Eychenne
 *
 * This file is part of Dolmen.
 *
 * Dolmen is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License (GPL) as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * Dolmen is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Dolmen. If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:  Julien Eychenne
 * Purpose:
 * Created: 12/04/2011
 */

#include "FileSidebar.h"

BrowserSideBar::BrowserSideBar(QToolBar *toolbar, QWidget *parent) :
    QWidget(parent)
{
	this->toolbar = toolbar;
	this->setupUi();
	connect(stacked_layout, SIGNAL(currentChanged(int)), this, SLOT(updateTitle(int)));
}

void BrowserSideBar::setupUi()
{
	// Chooser
	choice_box = new QComboBox;
	choice_box ->setFocusPolicy(Qt::NoFocus);


	// widget stack
	stacked_layout = new QStackedLayout;


#ifdef Q_OS_MAC
	this->setContentsMargins(0,0,0,0);
    label_project = new QLabel(tr("PROJECT"));
    label_project->setContentsMargins(10,5,0,0);
    label_project->setStyleSheet("QLabel { color:#738192; font-weight:bold; font-family: Lucida Grande; font-size: 11pt; };");
	QVBoxLayout *vl = new QVBoxLayout;
	vl->setContentsMargins(0,0,0,0);
    vl->addWidget(label_project);

	toolbar->addWidget(choice_box);
	vl->addLayout(stacked_layout);
	this->setLayout(vl);
#else
    label_project = NULL;
	QHBoxLayout *hlayout = new QHBoxLayout;
	//hlayout->addSpacing(20);
	hlayout->addWidget(choice_box);
	//hlayout->addSpacing(20);

	QVBoxLayout *main_layout = new QVBoxLayout;
	main_layout->addLayout(hlayout);
	main_layout->addLayout(stacked_layout);
	this->setLayout(main_layout);
#endif

	connect(choice_box, SIGNAL(activated(int)), stacked_layout, SLOT(setCurrentIndex(int)));
}

QLabel * BrowserSideBar::label() const
{
    return label_project;
}

void BrowserSideBar::addItem(QWidget *w, const QString &title)
{
	stacked_layout->addWidget(w);
	choice_box->addItem(title);
}

void BrowserSideBar::setCurrentIndex(int i)
{
	choice_box->setCurrentIndex(i);
}

void BrowserSideBar::updateTitle(int index)
{
#ifdef Q_OS_MAC
	if (index == 0)
        emit updateUi();
	else
        label_project->setText(tr("BOOKMARKS"));
#else
    Q_UNUSED(index)
#endif
}



