/*
 * OutputTab.cpp
 *
 * Copyright (C) 2010-2013 Julien Eychenne
 *
 * This file is part of Dolmen.
 *
 * Dolmen is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License (GPL) as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * Dolmen is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Dolmen. If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:  Julien Eychenne
 * Purpose: new implementation for the standard output tab
 * Created: 23/4/2012
 */

#include "OutputTab.h"

OutputTab::OutputTab()
{
    tabWidget = NULL;
    m_tab = NULL;
}

void OutputTab::onRightClick(const QPoint &pos)
{
    ContextMenu *menu = new ContextMenu(m_tab);

    QAction *clearAction = new QAction(m_tab);
    clearAction->setText(tr("Clear output"));
    menu->addAction(clearAction);
    QAction *saveAction = new QAction(m_tab);
    saveAction->setText(tr("Save..."));
    menu->addAction(saveAction);
    saveAction->setEnabled(false);

    connect(clearAction, SIGNAL(triggered()), this, SLOT(clear()));
    menu->display(pos);
}

void OutputTab::write(const QString &text)
{
    tabWidget->setCurrentWidget(m_tab);
    m_tab->append("<font face = \"" DM_MONO_FONT "\">" + text + "</font>");
}

void OutputTab::error(const QString &text)
{
    tabWidget->setCurrentWidget(m_tab);
    m_tab->append("<font face = \"" DM_MONO_FONT "\" color = \"red\">" + text + "</font>");
}

void OutputTab::clear()
{
    m_tab->clear();
}

//QTextEdit * OutputTab::editor() const
//{
//    return m_tab;
//}

void OutputTab::setEditor(QTabWidget *parent, QTextEdit *ed)
{
    tabWidget = parent;
    m_tab = ed;
    m_tab->setContextMenuPolicy(Qt::CustomContextMenu);
    m_tab->setReadOnly(true);
    m_tab->setObjectName("Output");

    connect(m_tab, SIGNAL(customContextMenuRequested(const QPoint &)), this, SLOT(onRightClick(const QPoint &)));
}
